# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/ComponentState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/ComponentState.proto',
  package='rst.cbse',
  serialized_pb='\n\x1drst/cbse/ComponentState.proto\x12\x08rst.cbse\"\xc4\x01\n\x0e\x43omponentState\x12-\n\x05state\x18\x01 \x02(\x0e\x32\x1e.rst.cbse.ComponentState.State\"\x82\x01\n\x05State\x12\x07\n\x03OFF\x10\x01\x12\x06\n\x02ON\x10\x02\x12\n\n\x06PAUSED\x10\x03\x12\r\n\tEXECUTION\x10\x04\x12\x12\n\x0eONLINELEARNING\x10\x05\x12\x13\n\x0fOFFLINELEARNING\x10\x06\x12\t\n\x05RESET\x10\x07\x12\n\n\x06LOADED\x10\x08\x12\r\n\tPERSISTED\x10\tB\x14\x42\x12\x43omponentStateType')



_COMPONENTSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='rst.cbse.ComponentState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OFF', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ON', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXECUTION', index=3, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ONLINELEARNING', index=4, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OFFLINELEARNING', index=5, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RESET', index=6, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOADED', index=7, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PERSISTED', index=8, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=110,
  serialized_end=240,
)


_COMPONENTSTATE = _descriptor.Descriptor(
  name='ComponentState',
  full_name='rst.cbse.ComponentState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='rst.cbse.ComponentState.state', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _COMPONENTSTATE_STATE,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=44,
  serialized_end=240,
)

_COMPONENTSTATE.fields_by_name['state'].enum_type = _COMPONENTSTATE_STATE
_COMPONENTSTATE_STATE.containing_type = _COMPONENTSTATE;
DESCRIPTOR.message_types_by_name['ComponentState'] = _COMPONENTSTATE

class ComponentState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _COMPONENTSTATE

  # @@protoc_insertion_point(class_scope:rst.cbse.ComponentState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ComponentStateType')
# @@protoc_insertion_point(module_scope)
