# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/monitoring/ProcessCues.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/monitoring/ProcessCues.proto',
  package='rst.monitoring',
  serialized_pb='\n rst/monitoring/ProcessCues.proto\x12\x0erst.monitoring\"\x80\x06\n\x0bProcessCues\x12\x0c\n\x03pid\x18\xe8\x07 \x02(\r\x12\r\n\x04name\x18\xe9\x07 \x01(\x0c\x12\x12\n\thost_name\x18\xea\x07 \x01(\x0c\x12\x15\n\x0c\x63ommand_line\x18\xeb\x07 \x01(\t\x12\x12\n\tunique_id\x18\x94N \x01(\x0c\x12.\n\x04\x63ues\x18\x01 \x03(\x0b\x32 .rst.monitoring.ProcessCues.Cues\x12\x33\n\x07threads\x18\n \x03(\x0b\x32\".rst.monitoring.ProcessCues.Thread\x12-\n\x08\x63hildren\x18\x14 \x03(\x0b\x32\x1b.rst.monitoring.ProcessCues\x1a\xab\x03\n\x04\x43ues\x12\x0f\n\x06source\x18\xe8\x07 \x02(\x0c\x12\r\n\x05utime\x18\x01 \x01(\x04\x12\r\n\x05stime\x18\x02 \x01(\x04\x12\x13\n\x0bnum_threads\x18\x03 \x01(\x03\x12\r\n\x05vsize\x18\x04 \x01(\x04\x12\x0b\n\x03rss\x18\x05 \x01(\x03\x12\x11\n\twall_time\x18\x06 \x01(\x04\x12\x14\n\x0cvirtual_time\x18\x07 \x01(\x04\x12\r\n\x05\x65time\x18\x08 \x01(\x04\x12\x14\n\x0cutime_scaled\x18\t \x01(\x04\x12\x14\n\x0cstime_scaled\x18\n \x01(\x04\x12\x18\n\x10wall_time_scaled\x18\x0b \x01(\x04\x12\x12\n\nstart_time\x18\x0c \x01(\x04\x12\r\n\x05rchar\x18\x1e \x01(\x04\x12\r\n\x05wchar\x18\x1f \x01(\x04\x12\x12\n\nread_bytes\x18  \x01(\x04\x12\x13\n\x0bwrite_bytes\x18! \x01(\x04\x12\x10\n\x08open_fds\x18\x32 \x01(\r\x12\x12\n\nopen_files\x18\x33 \x01(\r\x12\x18\n\x10open_connections\x18< \x01(\r\x12\x16\n\x0ereceived_bytes\x18\x46 \x01(\x04\x12\x12\n\nsent_bytes\x18G \x01(\x04\x1aS\n\x06Thread\x12\x0c\n\x04name\x18\x01 \x01(\x0c\x12\x0b\n\x03tid\x18\x02 \x01(\r\x12.\n\x04\x63ues\x18\n \x03(\x0b\x32 .rst.monitoring.ProcessCues.CuesB\x11\x42\x0fProcessCuesType')




_PROCESSCUES_CUES = _descriptor.Descriptor(
  name='Cues',
  full_name='rst.monitoring.ProcessCues.Cues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='source', full_name='rst.monitoring.ProcessCues.Cues.source', index=0,
      number=1000, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utime', full_name='rst.monitoring.ProcessCues.Cues.utime', index=1,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stime', full_name='rst.monitoring.ProcessCues.Cues.stime', index=2,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='num_threads', full_name='rst.monitoring.ProcessCues.Cues.num_threads', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vsize', full_name='rst.monitoring.ProcessCues.Cues.vsize', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rss', full_name='rst.monitoring.ProcessCues.Cues.rss', index=5,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wall_time', full_name='rst.monitoring.ProcessCues.Cues.wall_time', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='virtual_time', full_name='rst.monitoring.ProcessCues.Cues.virtual_time', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='etime', full_name='rst.monitoring.ProcessCues.Cues.etime', index=8,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='utime_scaled', full_name='rst.monitoring.ProcessCues.Cues.utime_scaled', index=9,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='stime_scaled', full_name='rst.monitoring.ProcessCues.Cues.stime_scaled', index=10,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wall_time_scaled', full_name='rst.monitoring.ProcessCues.Cues.wall_time_scaled', index=11,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='rst.monitoring.ProcessCues.Cues.start_time', index=12,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='rchar', full_name='rst.monitoring.ProcessCues.Cues.rchar', index=13,
      number=30, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wchar', full_name='rst.monitoring.ProcessCues.Cues.wchar', index=14,
      number=31, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='read_bytes', full_name='rst.monitoring.ProcessCues.Cues.read_bytes', index=15,
      number=32, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='write_bytes', full_name='rst.monitoring.ProcessCues.Cues.write_bytes', index=16,
      number=33, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_fds', full_name='rst.monitoring.ProcessCues.Cues.open_fds', index=17,
      number=50, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_files', full_name='rst.monitoring.ProcessCues.Cues.open_files', index=18,
      number=51, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_connections', full_name='rst.monitoring.ProcessCues.Cues.open_connections', index=19,
      number=60, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='received_bytes', full_name='rst.monitoring.ProcessCues.Cues.received_bytes', index=20,
      number=70, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='sent_bytes', full_name='rst.monitoring.ProcessCues.Cues.sent_bytes', index=21,
      number=71, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=309,
  serialized_end=736,
)

_PROCESSCUES_THREAD = _descriptor.Descriptor(
  name='Thread',
  full_name='rst.monitoring.ProcessCues.Thread',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessCues.Thread.name', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tid', full_name='rst.monitoring.ProcessCues.Thread.tid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cues', full_name='rst.monitoring.ProcessCues.Thread.cues', index=2,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=738,
  serialized_end=821,
)

_PROCESSCUES = _descriptor.Descriptor(
  name='ProcessCues',
  full_name='rst.monitoring.ProcessCues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='rst.monitoring.ProcessCues.pid', index=0,
      number=1000, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessCues.name', index=1,
      number=1001, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='rst.monitoring.ProcessCues.host_name', index=2,
      number=1002, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='command_line', full_name='rst.monitoring.ProcessCues.command_line', index=3,
      number=1003, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unique_id', full_name='rst.monitoring.ProcessCues.unique_id', index=4,
      number=10004, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cues', full_name='rst.monitoring.ProcessCues.cues', index=5,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='threads', full_name='rst.monitoring.ProcessCues.threads', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='children', full_name='rst.monitoring.ProcessCues.children', index=7,
      number=20, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PROCESSCUES_CUES, _PROCESSCUES_THREAD, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=53,
  serialized_end=821,
)

_PROCESSCUES_CUES.containing_type = _PROCESSCUES;
_PROCESSCUES_THREAD.fields_by_name['cues'].message_type = _PROCESSCUES_CUES
_PROCESSCUES_THREAD.containing_type = _PROCESSCUES;
_PROCESSCUES.fields_by_name['cues'].message_type = _PROCESSCUES_CUES
_PROCESSCUES.fields_by_name['threads'].message_type = _PROCESSCUES_THREAD
_PROCESSCUES.fields_by_name['children'].message_type = _PROCESSCUES
DESCRIPTOR.message_types_by_name['ProcessCues'] = _PROCESSCUES

class ProcessCues(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class Cues(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PROCESSCUES_CUES

    # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues.Cues)

  class Thread(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PROCESSCUES_THREAD

    # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues.Thread)
  DESCRIPTOR = _PROCESSCUES

  # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessCues)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\017ProcessCuesType')
# @@protoc_insertion_point(module_scope)
