# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/devices/flexirob/RobotState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/devices/flexirob/RobotState.proto',
  package='rst.devices.flexirob',
  serialized_pb='\n%rst/devices/flexirob/RobotState.proto\x12\x14rst.devices.flexirob\"\xdc\x02\n\nRobotState\x12\x45\n\nconnection\x18\x01 \x01(\x0e\x32\x31.rst.devices.flexirob.RobotState.ConnectionStatus\x12=\n\x06motion\x18\x02 \x01(\x0e\x32-.rst.devices.flexirob.RobotState.MotionStatus\x12<\n\x06\x66orces\x18\x03 \x01(\x0e\x32,.rst.devices.flexirob.RobotState.ForceStatus\"4\n\x10\x43onnectionStatus\x12\r\n\tCONNECTED\x10\x01\x12\x11\n\rNOT_CONNECTED\x10\x02\")\n\x0cMotionStatus\x12\r\n\tCONVERGED\x10\x01\x12\n\n\x06MOVING\x10\x02\")\n\x0b\x46orceStatus\x12\x0c\n\x08\x43ONSTANT\x10\x01\x12\x0c\n\x08\x43HANGING\x10\x02\x42\x10\x42\x0eRobotStateType')



_ROBOTSTATE_CONNECTIONSTATUS = _descriptor.EnumDescriptor(
  name='ConnectionStatus',
  full_name='rst.devices.flexirob.RobotState.ConnectionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONNECTED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOT_CONNECTED', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=274,
  serialized_end=326,
)

_ROBOTSTATE_MOTIONSTATUS = _descriptor.EnumDescriptor(
  name='MotionStatus',
  full_name='rst.devices.flexirob.RobotState.MotionStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONVERGED', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MOVING', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=328,
  serialized_end=369,
)

_ROBOTSTATE_FORCESTATUS = _descriptor.EnumDescriptor(
  name='ForceStatus',
  full_name='rst.devices.flexirob.RobotState.ForceStatus',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CONSTANT', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGING', index=1, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=371,
  serialized_end=412,
)


_ROBOTSTATE = _descriptor.Descriptor(
  name='RobotState',
  full_name='rst.devices.flexirob.RobotState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='connection', full_name='rst.devices.flexirob.RobotState.connection', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='motion', full_name='rst.devices.flexirob.RobotState.motion', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='forces', full_name='rst.devices.flexirob.RobotState.forces', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROBOTSTATE_CONNECTIONSTATUS,
    _ROBOTSTATE_MOTIONSTATUS,
    _ROBOTSTATE_FORCESTATUS,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=64,
  serialized_end=412,
)

_ROBOTSTATE.fields_by_name['connection'].enum_type = _ROBOTSTATE_CONNECTIONSTATUS
_ROBOTSTATE.fields_by_name['motion'].enum_type = _ROBOTSTATE_MOTIONSTATUS
_ROBOTSTATE.fields_by_name['forces'].enum_type = _ROBOTSTATE_FORCESTATUS
_ROBOTSTATE_CONNECTIONSTATUS.containing_type = _ROBOTSTATE;
_ROBOTSTATE_MOTIONSTATUS.containing_type = _ROBOTSTATE;
_ROBOTSTATE_FORCESTATUS.containing_type = _ROBOTSTATE;
DESCRIPTOR.message_types_by_name['RobotState'] = _ROBOTSTATE

class RobotState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _ROBOTSTATE

  # @@protoc_insertion_point(class_scope:rst.devices.flexirob.RobotState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016RobotStateType')
# @@protoc_insertion_point(module_scope)
