# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/kinematics/JointJerks.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/kinematics/JointJerks.proto',
  package='rst.kinematics',
  serialized_pb='\n\x1frst/kinematics/JointJerks.proto\x12\x0erst.kinematics\"\x1f\n\nJointJerks\x12\x11\n\x05jerks\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\x10\x42\x0eJointJerksType')




_JOINTJERKS = _descriptor.Descriptor(
  name='JointJerks',
  full_name='rst.kinematics.JointJerks',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='jerks', full_name='rst.kinematics.JointJerks.jerks', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=51,
  serialized_end=82,
)

DESCRIPTOR.message_types_by_name['JointJerks'] = _JOINTJERKS

class JointJerks(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTJERKS

  # @@protoc_insertion_point(class_scope:rst.kinematics.JointJerks)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016JointJerksType')
_JOINTJERKS.fields_by_name['jerks'].has_options = True
_JOINTJERKS.fields_by_name['jerks']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)
