# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/JointState.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.kinematics.JointAngles_pb2
import rst.kinematics.JointVelocities_pb2
import rst.dynamics.JointTorques_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/JointState.proto',
  package='rst.robot',
  serialized_pb='\n\x1arst/robot/JointState.proto\x12\trst.robot\x1a rst/kinematics/JointAngles.proto\x1a$rst/kinematics/JointVelocities.proto\x1a\x1frst/dynamics/JointTorques.proto\"\x9b\x01\n\nJointState\x12+\n\x06\x61ngles\x18\x01 \x02(\x0b\x32\x1b.rst.kinematics.JointAngles\x12\x33\n\nvelocities\x18\x02 \x02(\x0b\x32\x1f.rst.kinematics.JointVelocities\x12+\n\x07torques\x18\x03 \x02(\x0b\x32\x1a.rst.dynamics.JointTorquesB\x10\x42\x0eJointStateType')




_JOINTSTATE = _descriptor.Descriptor(
  name='JointState',
  full_name='rst.robot.JointState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='angles', full_name='rst.robot.JointState.angles', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocities', full_name='rst.robot.JointState.velocities', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='torques', full_name='rst.robot.JointState.torques', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=147,
  serialized_end=302,
)

_JOINTSTATE.fields_by_name['angles'].message_type = rst.kinematics.JointAngles_pb2._JOINTANGLES
_JOINTSTATE.fields_by_name['velocities'].message_type = rst.kinematics.JointVelocities_pb2._JOINTVELOCITIES
_JOINTSTATE.fields_by_name['torques'].message_type = rst.dynamics.JointTorques_pb2._JOINTTORQUES
DESCRIPTOR.message_types_by_name['JointState'] = _JOINTSTATE

class JointState(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _JOINTSTATE

  # @@protoc_insertion_point(class_scope:rst.robot.JointState)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016JointStateType')
# @@protoc_insertion_point(module_scope)
