# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/PersonHypothesis.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.math.Vec2DFloat_pb2
import rst.vision.LocatedFace_pb2
import rst.tracking.TrackingInfo_pb2
import rst.hri.Body_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/PersonHypothesis.proto',
  package='rst.hri',
  serialized_pb='\n\x1erst/hri/PersonHypothesis.proto\x12\x07rst.hri\x1a\x19rst/math/Vec2DFloat.proto\x1a\x1crst/vision/LocatedFace.proto\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x12rst/hri/Body.proto\"\xf0\x03\n\x10PersonHypothesis\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12%\n\x04\x66\x61\x63\x65\x18\x03 \x01(\x0b\x32\x17.rst.vision.LocatedFace\x12\x1b\n\x04\x62ody\x18\n \x01(\x0b\x32\r.rst.hri.Body\x12/\n\x03\x61ge\x18( \x01(\x0b\x32\".rst.hri.PersonHypothesis.AgeRange\x12\x39\n\x06gender\x18* \x01(\x0e\x32 .rst.hri.PersonHypothesis.Gender:\x07UNKNOWN\x12\x0c\n\x04name\x18, \x01(\t\x12\x14\n\x0chuman_height\x18- \x01(\x02\x12\x44\n\x11\x61ttention_targets\x18\x32 \x03(\x0b\x32).rst.hri.PersonHypothesis.AttentionTarget\x1a,\n\x08\x41geRange\x12\x0f\n\x07\x61ge_min\x18\x01 \x02(\x02\x12\x0f\n\x07\x61ge_max\x18\x02 \x02(\x02\x1a\x34\n\x0f\x41ttentionTarget\x12\x0c\n\x04name\x18\x01 \x02(\x0c\x12\x13\n\x0bprobability\x18\x02 \x02(\x02\"+\n\x06Gender\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04MALE\x10\x01\x12\n\n\x06\x46\x45MALE\x10\x02\x42\x16\x42\x14PersonHypothesisType')



_PERSONHYPOTHESIS_GENDER = _descriptor.EnumDescriptor(
  name='Gender',
  full_name='rst.hri.PersonHypothesis.Gender',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MALE', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEMALE', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=607,
  serialized_end=650,
)


_PERSONHYPOTHESIS_AGERANGE = _descriptor.Descriptor(
  name='AgeRange',
  full_name='rst.hri.PersonHypothesis.AgeRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='age_min', full_name='rst.hri.PersonHypothesis.AgeRange.age_min', index=0,
      number=1, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age_max', full_name='rst.hri.PersonHypothesis.AgeRange.age_max', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=507,
  serialized_end=551,
)

_PERSONHYPOTHESIS_ATTENTIONTARGET = _descriptor.Descriptor(
  name='AttentionTarget',
  full_name='rst.hri.PersonHypothesis.AttentionTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.hri.PersonHypothesis.AttentionTarget.name', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probability', full_name='rst.hri.PersonHypothesis.AttentionTarget.probability', index=1,
      number=2, type=2, cpp_type=6, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=553,
  serialized_end=605,
)

_PERSONHYPOTHESIS = _descriptor.Descriptor(
  name='PersonHypothesis',
  full_name='rst.hri.PersonHypothesis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.hri.PersonHypothesis.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.hri.PersonHypothesis.face', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='body', full_name='rst.hri.PersonHypothesis.body', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age', full_name='rst.hri.PersonHypothesis.age', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender', full_name='rst.hri.PersonHypothesis.gender', index=4,
      number=42, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.hri.PersonHypothesis.name', index=5,
      number=44, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='human_height', full_name='rst.hri.PersonHypothesis.human_height', index=6,
      number=45, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attention_targets', full_name='rst.hri.PersonHypothesis.attention_targets', index=7,
      number=50, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PERSONHYPOTHESIS_AGERANGE, _PERSONHYPOTHESIS_ATTENTIONTARGET, ],
  enum_types=[
    _PERSONHYPOTHESIS_GENDER,
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=154,
  serialized_end=650,
)

_PERSONHYPOTHESIS_AGERANGE.containing_type = _PERSONHYPOTHESIS;
_PERSONHYPOTHESIS_ATTENTIONTARGET.containing_type = _PERSONHYPOTHESIS;
_PERSONHYPOTHESIS.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_PERSONHYPOTHESIS.fields_by_name['face'].message_type = rst.vision.LocatedFace_pb2._LOCATEDFACE
_PERSONHYPOTHESIS.fields_by_name['body'].message_type = rst.hri.Body_pb2._BODY
_PERSONHYPOTHESIS.fields_by_name['age'].message_type = _PERSONHYPOTHESIS_AGERANGE
_PERSONHYPOTHESIS.fields_by_name['gender'].enum_type = _PERSONHYPOTHESIS_GENDER
_PERSONHYPOTHESIS.fields_by_name['attention_targets'].message_type = _PERSONHYPOTHESIS_ATTENTIONTARGET
_PERSONHYPOTHESIS_GENDER.containing_type = _PERSONHYPOTHESIS;
DESCRIPTOR.message_types_by_name['PersonHypothesis'] = _PERSONHYPOTHESIS

class PersonHypothesis(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class AgeRange(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PERSONHYPOTHESIS_AGERANGE

    # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis.AgeRange)

  class AttentionTarget(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _PERSONHYPOTHESIS_ATTENTIONTARGET

    # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis.AttentionTarget)
  DESCRIPTOR = _PERSONHYPOTHESIS

  # @@protoc_insertion_point(class_scope:rst.hri.PersonHypothesis)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024PersonHypothesisType')
# @@protoc_insertion_point(module_scope)
