# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cogimon/ModelComponentConfig.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cogimon/ModelComponentConfig.proto',
  package='rst.cogimon',
  serialized_pb='\n&rst/cogimon/ModelComponentConfig.proto\x12\x0brst.cogimon\"\x85\x01\n\x14ModelComponentConfig\x12\x16\n\x0e\x63omponent_name\x18\x01 \x02(\t\x12\x16\n\x0e\x63omponent_type\x18\x02 \x02(\t\x12\x19\n\x11\x63omponent_package\x18\x03 \x02(\t\x12\x12\n\nmodel_name\x18\x04 \x02(\t\x12\x0e\n\x06script\x18\x05 \x01(\tB\x1a\x42\x18ModelComponentConfigType')




_MODELCOMPONENTCONFIG = _descriptor.Descriptor(
  name='ModelComponentConfig',
  full_name='rst.cogimon.ModelComponentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='component_name', full_name='rst.cogimon.ModelComponentConfig.component_name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='component_type', full_name='rst.cogimon.ModelComponentConfig.component_type', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='component_package', full_name='rst.cogimon.ModelComponentConfig.component_package', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='model_name', full_name='rst.cogimon.ModelComponentConfig.model_name', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='script', full_name='rst.cogimon.ModelComponentConfig.script', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=56,
  serialized_end=189,
)

DESCRIPTOR.message_types_by_name['ModelComponentConfig'] = _MODELCOMPONENTCONFIG

class ModelComponentConfig(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _MODELCOMPONENTCONFIG

  # @@protoc_insertion_point(class_scope:rst.cogimon.ModelComponentConfig)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\030ModelComponentConfigType')
# @@protoc_insertion_point(module_scope)
