# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/vision/HeadObject.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.geometry.BoundingBox_pb2
import rst.tracking.TrackingInfo_pb2
import rst.vision.Face_pb2
import rst.math.Vec3DFloat_pb2
import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/vision/HeadObject.proto',
  package='rst.vision',
  serialized_pb='\n\x1brst/vision/HeadObject.proto\x12\nrst.vision\x1a\x1erst/geometry/BoundingBox.proto\x1a\x1frst/tracking/TrackingInfo.proto\x1a\x15rst/vision/Face.proto\x1a\x19rst/math/Vec3DFloat.proto\x1a-rst/classification/ClassificationResult.proto\"\x87\x04\n\nHeadObject\x12\x31\n\rtracking_info\x18\x01 \x01(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12)\n\x06region\x18\x02 \x01(\x0b\x32\x19.rst.geometry.BoundingBox\x12&\n\x08position\x18\x03 \x01(\x0b\x32\x14.rst.math.Vec3DFloat\x12\"\n\x04pose\x18\x04 \x01(\x0b\x32\x14.rst.math.Vec3DFloat\x12\x31\n\x05\x66\x61\x63\x65s\x18\x06 \x03(\x0b\x32\".rst.vision.HeadObject.LabeledFace\x12\x1c\n\x14speaking_probability\x18\x07 \x01(\x02\x12\x13\n\x0bvfoa_target\x18\x08 \x01(\x0c\x12:\n\x08identity\x18\t \x01(\x0b\x32(.rst.classification.ClassificationResult\x12\x38\n\x06gender\x18\n \x01(\x0b\x32(.rst.classification.ClassificationResult\x12\x35\n\x03\x61ge\x18\x0b \x01(\x0b\x32(.rst.classification.ClassificationResult\x1a<\n\x0bLabeledFace\x12\r\n\x05label\x18\x01 \x02(\x0c\x12\x1e\n\x04\x66\x61\x63\x65\x18\x02 \x02(\x0b\x32\x10.rst.vision.FaceB\x10\x42\x0eHeadObjectType')




_HEADOBJECT_LABELEDFACE = _descriptor.Descriptor(
  name='LabeledFace',
  full_name='rst.vision.HeadObject.LabeledFace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='rst.vision.HeadObject.LabeledFace.label', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='face', full_name='rst.vision.HeadObject.LabeledFace.face', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=665,
  serialized_end=725,
)

_HEADOBJECT = _descriptor.Descriptor(
  name='HeadObject',
  full_name='rst.vision.HeadObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tracking_info', full_name='rst.vision.HeadObject.tracking_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='region', full_name='rst.vision.HeadObject.region', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='position', full_name='rst.vision.HeadObject.position', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pose', full_name='rst.vision.HeadObject.pose', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='faces', full_name='rst.vision.HeadObject.faces', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='speaking_probability', full_name='rst.vision.HeadObject.speaking_probability', index=5,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vfoa_target', full_name='rst.vision.HeadObject.vfoa_target', index=6,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='identity', full_name='rst.vision.HeadObject.identity', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='gender', full_name='rst.vision.HeadObject.gender', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='age', full_name='rst.vision.HeadObject.age', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_HEADOBJECT_LABELEDFACE, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=206,
  serialized_end=725,
)

_HEADOBJECT_LABELEDFACE.fields_by_name['face'].message_type = rst.vision.Face_pb2._FACE
_HEADOBJECT_LABELEDFACE.containing_type = _HEADOBJECT;
_HEADOBJECT.fields_by_name['tracking_info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_HEADOBJECT.fields_by_name['region'].message_type = rst.geometry.BoundingBox_pb2._BOUNDINGBOX
_HEADOBJECT.fields_by_name['position'].message_type = rst.math.Vec3DFloat_pb2._VEC3DFLOAT
_HEADOBJECT.fields_by_name['pose'].message_type = rst.math.Vec3DFloat_pb2._VEC3DFLOAT
_HEADOBJECT.fields_by_name['faces'].message_type = _HEADOBJECT_LABELEDFACE
_HEADOBJECT.fields_by_name['identity'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
_HEADOBJECT.fields_by_name['gender'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
_HEADOBJECT.fields_by_name['age'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['HeadObject'] = _HEADOBJECT

class HeadObject(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType

  class LabeledFace(_message.Message):
    __metaclass__ = _reflection.GeneratedProtocolMessageType
    DESCRIPTOR = _HEADOBJECT_LABELEDFACE

    # @@protoc_insertion_point(class_scope:rst.vision.HeadObject.LabeledFace)
  DESCRIPTOR = _HEADOBJECT

  # @@protoc_insertion_point(class_scope:rst.vision.HeadObject)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\016HeadObjectType')
# @@protoc_insertion_point(module_scope)
