# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/monitoring/ProcessAnomaly.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/monitoring/ProcessAnomaly.proto',
  package='rst.monitoring',
  serialized_pb='\n#rst/monitoring/ProcessAnomaly.proto\x12\x0erst.monitoring\"R\n\x0eProcessAnomaly\x12\x0c\n\x03pid\x18\xe8\x07 \x02(\r\x12\r\n\x04name\x18\xe9\x07 \x01(\x0c\x12\x12\n\thost_name\x18\xea\x07 \x01(\x0c\x12\x0f\n\x07reasons\x18\x01 \x03(\tB\x14\x42\x12ProcessAnomalyType')




_PROCESSANOMALY = _descriptor.Descriptor(
  name='ProcessAnomaly',
  full_name='rst.monitoring.ProcessAnomaly',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='rst.monitoring.ProcessAnomaly.pid', index=0,
      number=1000, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='rst.monitoring.ProcessAnomaly.name', index=1,
      number=1001, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='rst.monitoring.ProcessAnomaly.host_name', index=2,
      number=1002, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value="",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reasons', full_name='rst.monitoring.ProcessAnomaly.reasons', index=3,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=55,
  serialized_end=137,
)

DESCRIPTOR.message_types_by_name['ProcessAnomaly'] = _PROCESSANOMALY

class ProcessAnomaly(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PROCESSANOMALY

  # @@protoc_insertion_point(class_scope:rst.monitoring.ProcessAnomaly)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\022ProcessAnomalyType')
# @@protoc_insertion_point(module_scope)
