# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/cbse/InputPort.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/cbse/InputPort.proto',
  package='rst.cbse',
  serialized_pb='\n\x18rst/cbse/InputPort.proto\x12\x08rst.cbse\"?\n\tInputPort\x12\r\n\x05scope\x18\x01 \x02(\t\x12\x12\n\nbuffersize\x18\x02 \x01(\x04\x12\x0f\n\x07\x66illing\x18\x03 \x01(\x04\x42\x0f\x42\rInputPortType')




_INPUTPORT = _descriptor.Descriptor(
  name='InputPort',
  full_name='rst.cbse.InputPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='rst.cbse.InputPort.scope', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=unicode("", "utf-8"),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='buffersize', full_name='rst.cbse.InputPort.buffersize', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filling', full_name='rst.cbse.InputPort.filling', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=38,
  serialized_end=101,
)

DESCRIPTOR.message_types_by_name['InputPort'] = _INPUTPORT

class InputPort(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _INPUTPORT

  # @@protoc_insertion_point(class_scope:rst.cbse.InputPort)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\rInputPortType')
# @@protoc_insertion_point(module_scope)
