# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/hri/PersonHypotheses.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.hri.PersonHypothesis_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/hri/PersonHypotheses.proto',
  package='rst.hri',
  serialized_pb='\n\x1erst/hri/PersonHypotheses.proto\x12\x07rst.hri\x1a\x1erst/hri/PersonHypothesis.proto\">\n\x10PersonHypotheses\x12*\n\x07persons\x18\x01 \x03(\x0b\x32\x19.rst.hri.PersonHypothesisB\x16\x42\x14PersonHypothesesType')




_PERSONHYPOTHESES = _descriptor.Descriptor(
  name='PersonHypotheses',
  full_name='rst.hri.PersonHypotheses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='persons', full_name='rst.hri.PersonHypotheses.persons', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=75,
  serialized_end=137,
)

_PERSONHYPOTHESES.fields_by_name['persons'].message_type = rst.hri.PersonHypothesis_pb2._PERSONHYPOTHESIS
DESCRIPTOR.message_types_by_name['PersonHypotheses'] = _PERSONHYPOTHESES

class PersonHypotheses(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _PERSONHYPOTHESES

  # @@protoc_insertion_point(class_scope:rst.hri.PersonHypotheses)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\024PersonHypothesesType')
# @@protoc_insertion_point(module_scope)
