# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/robot/Weights.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)




DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/robot/Weights.proto',
  package='rst.robot',
  serialized_pb='\n\x17rst/robot/Weights.proto\x12\trst.robot\"\x1e\n\x07Weights\x12\x13\n\x07weights\x18\x01 \x03(\x02\x42\x02\x10\x01\x42\rB\x0bWeightsType')




_WEIGHTS = _descriptor.Descriptor(
  name='Weights',
  full_name='rst.robot.Weights',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='weights', full_name='rst.robot.Weights.weights', index=0,
      number=1, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=38,
  serialized_end=68,
)

DESCRIPTOR.message_types_by_name['Weights'] = _WEIGHTS

class Weights(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _WEIGHTS

  # @@protoc_insertion_point(class_scope:rst.robot.Weights)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\013WeightsType')
_WEIGHTS.fields_by_name['weights'].has_options = True
_WEIGHTS.fields_by_name['weights']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), '\020\001')
# @@protoc_insertion_point(module_scope)
