# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/tracking/TrackedPolygonalPatch3D.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.tracking.TrackingInfo_pb2
import rst.geometry.PolygonalPatch3D_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/tracking/TrackedPolygonalPatch3D.proto',
  package='rst.tracking',
  serialized_pb='\n*rst/tracking/TrackedPolygonalPatch3D.proto\x12\x0crst.tracking\x1a\x1frst/tracking/TrackingInfo.proto\x1a#rst/geometry/PolygonalPatch3D.proto\"r\n\x17TrackedPolygonalPatch3D\x12(\n\x04info\x18\x01 \x02(\x0b\x32\x1a.rst.tracking.TrackingInfo\x12-\n\x05patch\x18\x02 \x02(\x0b\x32\x1e.rst.geometry.PolygonalPatch3DB\x1d\x42\x1bTrackedPolygonalPatch3DType')




_TRACKEDPOLYGONALPATCH3D = _descriptor.Descriptor(
  name='TrackedPolygonalPatch3D',
  full_name='rst.tracking.TrackedPolygonalPatch3D',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='rst.tracking.TrackedPolygonalPatch3D.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='patch', full_name='rst.tracking.TrackedPolygonalPatch3D.patch', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=130,
  serialized_end=244,
)

_TRACKEDPOLYGONALPATCH3D.fields_by_name['info'].message_type = rst.tracking.TrackingInfo_pb2._TRACKINGINFO
_TRACKEDPOLYGONALPATCH3D.fields_by_name['patch'].message_type = rst.geometry.PolygonalPatch3D_pb2._POLYGONALPATCH3D
DESCRIPTOR.message_types_by_name['TrackedPolygonalPatch3D'] = _TRACKEDPOLYGONALPATCH3D

class TrackedPolygonalPatch3D(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _TRACKEDPOLYGONALPATCH3D

  # @@protoc_insertion_point(class_scope:rst.tracking.TrackedPolygonalPatch3D)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\033TrackedPolygonalPatch3DType')
# @@protoc_insertion_point(module_scope)
