# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: rst/classification/ClassificationResults.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)


import rst.classification.ClassificationResult_pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='rst/classification/ClassificationResults.proto',
  package='rst.classification',
  serialized_pb='\n.rst/classification/ClassificationResults.proto\x12\x12rst.classification\x1a-rst/classification/ClassificationResult.proto\"R\n\x15\x43lassificationResults\x12\x39\n\x07\x63lasses\x18\x01 \x03(\x0b\x32(.rst.classification.ClassificationResultB\x1b\x42\x19\x43lassificationResultsType')




_CLASSIFICATIONRESULTS = _descriptor.Descriptor(
  name='ClassificationResults',
  full_name='rst.classification.ClassificationResults',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='classes', full_name='rst.classification.ClassificationResults.classes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  extension_ranges=[],
  serialized_start=117,
  serialized_end=199,
)

_CLASSIFICATIONRESULTS.fields_by_name['classes'].message_type = rst.classification.ClassificationResult_pb2._CLASSIFICATIONRESULT
DESCRIPTOR.message_types_by_name['ClassificationResults'] = _CLASSIFICATIONRESULTS

class ClassificationResults(_message.Message):
  __metaclass__ = _reflection.GeneratedProtocolMessageType
  DESCRIPTOR = _CLASSIFICATIONRESULTS

  # @@protoc_insertion_point(class_scope:rst.classification.ClassificationResults)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), 'B\031ClassificationResultsType')
# @@protoc_insertion_point(module_scope)
